@@ -59,7 +59,7 @@ extern proplist_t orig_wmaker;		/* original WindowMaker file */
 extern proplist_t plist_changed;
 extern proplist_t pl_yes;
 
-extern proplist_t  orig_rootmenu;	/* original WMRootMenu file */
+extern proplist_t   orig_rootmenu;	/* original WMRootMenu file */
 extern GtkWidget   *log_text;
 extern GtkTooltips *tooltips;
 
@@ -256,8 +256,10 @@ make_toolbar (bool_t noinet)
  *	toolbar widget
  */
 {
-   GtkWidget *toolbar = gtk_toolbar_new (GTK_ORIENTATION_HORIZONTAL,
-					 GTK_TOOLBAR_ICONS);
+   GtkWidget *toolbar = gtk_toolbar_new ();
+   gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar),
+				GTK_ORIENTATION_HORIZONTAL);
+   gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
 
    gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
 			    NULL, _("Exit wmakerconf"),
@@ -426,44 +428,33 @@ readme (GtkWidget *w, gpointer ptr)
 				 GTK_OBJECT (window));
    
       {
-	 GtkWidget *text, *vscrollbar, *hscrollbar, *table;
-	 char	buffer [MAXSTRLEN];
+	 GtkWidget     *text_view, *scrollw;
+	 GtkTextBuffer *text_buffer;
+	 GtkTextIter    iter;
+	 char	        buffer [MAXSTRLEN];
       
-	 table = gtk_table_new (2, 2, FALSE);
-	 gtk_table_set_row_spacing (GTK_TABLE (table), 0, 2);
-	 gtk_table_set_col_spacing (GTK_TABLE (table), 0, 2);
-	 gtk_widget_show (table);
+	 scrollw = gtk_scrolled_window_new (NULL, NULL);
+	 gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollw),
+					 GTK_POLICY_AUTOMATIC,
+				         GTK_POLICY_AUTOMATIC);
 	 gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (window)->vbox), 5);
-	 gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox), table,
+	 gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox), scrollw,
 			     TRUE, TRUE, 5);
 
-	 text = gtk_text_new (NULL, NULL);
-	 gtk_text_set_editable (GTK_TEXT (text), FALSE);
-	 gtk_table_attach (GTK_TABLE (table), text, 1, 2, 0, 1,
-			   GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-			   GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0);
-	 gtk_widget_show (text);
+	 text_view = gtk_text_view_new ();
+	 gtk_text_view_set_editable (GTK_TEXT_VIEW (text_view), FALSE);
+	 gtk_container_add (GTK_CONTAINER (scrollw), text_view);
+	 gtk_widget_realize (text_view);
+	 gtk_text_view_set_editable (GTK_TEXT_VIEW (text_view), NO);
 
-	 hscrollbar = gtk_hscrollbar_new (GTK_TEXT (text)->hadj);
-	 gtk_table_attach (GTK_TABLE (table), hscrollbar, 1, 2, 1, 2,
-			   GTK_EXPAND | GTK_FILL | GTK_SHRINK, GTK_FILL, 0, 0);
-	 gtk_widget_show (hscrollbar);
-
-	 vscrollbar = gtk_vscrollbar_new (GTK_TEXT (text)->vadj);
-	 gtk_table_attach (GTK_TABLE (table), vscrollbar, 0, 1, 0, 2,
-			   GTK_FILL, GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0);
-	 gtk_widget_show (vscrollbar);
-
-	 gtk_text_freeze (GTK_TEXT (text));
-
-	 gtk_widget_realize (text);
-	 gtk_text_set_editable (GTK_TEXT (text), NO);
-
-	 while (fgets (buffer, MAXSTRLEN, input))
-	    gtk_text_insert (GTK_TEXT (text), NULL, NULL, NULL, buffer, -1);
+	 text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_view));
+	 while (fgets (buffer, MAXSTRLEN, input)) {
+	    gtk_text_buffer_get_iter_at_offset (text_buffer, &iter, -1);
+	    gtk_text_buffer_insert (text_buffer, &iter, buffer, -1);
+	 }
 	 fclose (input);
       }
-      gtk_widget_set_usize (window, 500, 500);
+      gtk_widget_set_usize (window, 550, 500);
    }
    if (!GTK_WIDGET_VISIBLE (window))
       gtk_widget_show_all (window);
@@ -481,9 +472,7 @@ wwwpage (GtkWidget *w, gpointer ptr)
 {
 #ifdef NETSCAPE
    char *www = (char *) ptr;
-   char *tmp = g_strdup_printf (
-       NETSCAPE " -remote 'openURL(%s,  new-window)' > /dev/null 2>&1 || "
-       NETSCAPE " '%s' &", www, www);
+   char *tmp = g_strdup_printf (NETSCAPE " '%s' &", www);
    system (tmp);
    Free (tmp);
 #endif
@@ -531,14 +520,18 @@ upgrade (GtkWidget *w, gpointer ptr)
 {
    FILE	*pipe = popen (PERL " " PKGDATADIR "/upgrade.pl 2>&1 &", "r");
    char	tmp [MAXSTRLEN];
+   GtkTextBuffer *buffer;
+   GtkTextIter    iter;
 
    gtk_widget_show_all (gtk_widget_get_toplevel (log_text));
    while (gtk_events_pending())
       gtk_main_iteration();
 
+   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (log_text));
    while (fgets (tmp, MAXSTRLEN, pipe))
    {
-      gtk_text_insert (GTK_TEXT (log_text), NULL, NULL, NULL, tmp, -1);
+      gtk_text_buffer_get_iter_at_offset (buffer, &iter, -1);
+      gtk_text_buffer_insert (buffer, &iter, tmp, -1);
       while (gtk_events_pending())
 	 gtk_main_iteration();
    }
@@ -572,7 +565,7 @@ static void
 load (GtkWidget *button, gpointer ptr)
 {
    GtkFileSelection *fs       = GTK_FILE_SELECTION (ptr);
-   char		    *filename = gtk_file_selection_get_filename (fs);
+   const char	    *filename = gtk_file_selection_get_filename (fs);
 
    if (!load_attributes (filename, NULL))
       dialog_popup (DIALOG_ERROR, NULL, NULL, _("Can't open selected file."));
