@@ -35,7 +35,7 @@ make_toolbar (bool_t noinet);
 GtkWidget *
 make_menubar (GtkWidget *logwindow, bool_t themes_menu, bool_t noinet);
 void
-toggle_save (bool_t enable, proplist_t *key);
+toggle_save (bool_t enable, proplist_t key);
 void
 enable_revert (void);
 
