@@ -95,7 +95,7 @@ main (int argc, char **argv)
 	       width  = height * image->width / image->height;
 	    
 	    scaled = RScaleImage (image, max (width, 22), max (height, 22));
-	    RDestroyImage (image);
+	    RReleaseImage (image);
 	 }
 	 else
 	    scaled = image;
@@ -135,7 +135,7 @@ main (int argc, char **argv)
 		  ptr++;
 	    }
 	 fclose (file);
-	 RDestroyImage (scaled);
+	 RReleaseImage (scaled);
       }
 #else  /* old wraster of wmaker < 0.62.0 */
       {
@@ -167,7 +167,7 @@ main (int argc, char **argv)
 	       }
 	    }
 	 fclose (file);
-	 RDestroyImage (scaled);
+	 RReleaseImage (scaled);
       }
 #endif    
       return 0;
