@@ -109,14 +109,12 @@ static void
 image_list (const char *path);
 static void
 make_preview (GtkWidget *entry, char *name);
-static void
-set_selection (GtkWidget *widget, gpointer ptr);
+static gint
+set_selection (GtkWidget *widget, GdkEventButton *event, gpointer ptr);
 static void
 accept_selection (GtkWidget *widget, gpointer ptr);
 static void
 show_previews (GtkWidget *table);
-static gint
-button_press (GtkWidget *widget, GdkEventButton *event, gpointer ptr);
 
 /*******************************************************************************
 
@@ -305,8 +303,6 @@ make_preview (GtkWidget *entry, char *name)
    data->button = gtk_button_new ();
 
    gtk_signal_connect (GTK_OBJECT (data->button), "button_press_event",
-		       GTK_SIGNAL_FUNC (button_press), NULL);
-   gtk_signal_connect (GTK_OBJECT (data->button), "clicked",
 		       GTK_SIGNAL_FUNC (set_selection), data);
    file_list = g_list_append (file_list, data);
 
@@ -338,12 +334,10 @@ make_preview (GtkWidget *entry, char *name)
    gtk_object_set_user_data (GTK_OBJECT (pixmap), entry);
 }
 
-static void
-set_selection (GtkWidget *widget, gpointer ptr)
+static gint
+set_selection (GtkWidget *widget, GdkEventButton *event, gpointer ptr)
 /*
  *  Change text entry if pixmap button is pressed.
- *
- *  No return value.
  */
 {
    GtkWidget	 *pixmap = gtk_object_get_user_data (GTK_OBJECT (widget));
@@ -351,6 +345,11 @@ set_selection (GtkWidget *widget, gpointer ptr)
    previewdata_t *data   = (previewdata_t *) ptr;
 
    gtk_entry_set_text (GTK_ENTRY (entry), g_basename (data->name));
+
+   if (event->type == GDK_2BUTTON_PRESS)
+     gtk_signal_emit_by_name (GTK_OBJECT (ok_button), "clicked");
+
+   return TRUE;
 }
 
 static void
@@ -433,15 +432,6 @@ new_scrolled_and_table (void)
    gtk_widget_show_all (scrolled);
 }
 
-static gint
-button_press (GtkWidget *widget, GdkEventButton *event, gpointer ptr)
-{
-   if (event->type == GDK_2BUTTON_PRESS)
-      gtk_signal_emit_by_name (GTK_OBJECT (ok_button), "clicked");
-   
-   return TRUE;
-}
-
 static void
 lock_filelist (GtkWidget *widget, gpointer ptr)
 {
