@@ -105,6 +105,47 @@ init_wraster_lib (void)
    }
 }
 
+/* We need this wrapper function since gdk_parse_color() no longer
+ * understands "rgb:RR/GG/BB".
+ */
+gboolean
+make_color(const gchar *spec, GdkColor *color)
+{
+  gboolean result;
+  gchar * newspec = spec;
+
+  if (strncmp(spec, "rgb:", 4) == 0) {
+    char * red_posn = spec + 4, * green_posn, * blue_posn;
+    int red_len, green_len, blue_len;
+    
+    green_posn = strchr(red_posn, '/');
+    if (!green_posn) return FALSE;
+    red_len = green_posn - red_posn;
+    green_posn++;
+    
+    blue_posn = strchr(green_posn, '/');
+    if (!blue_posn) return FALSE;
+    green_len = blue_posn - green_posn;
+    blue_posn++;
+    blue_len = strlen(spec) - (blue_posn - spec);
+
+    if (red_len != green_len || green_len != blue_len ||
+	red_len < 1 || red_len > 4)
+      return FALSE;
+    
+    newspec = malloc(3 * red_len + 2);
+    strcpy(newspec, "#");
+    strncat(newspec, red_posn, red_len);
+    strncat(newspec, green_posn, red_len);
+    strncat(newspec, blue_posn, red_len);
+  }
+
+  result = gdk_color_parse (newspec, color);
+  if (newspec != spec)
+    free (newspec);
+  return result;
+}
+
 GtkWidget *
 make_image (const char *filename, int width, int height, GtkWidget *preview)
 {
@@ -133,7 +174,7 @@ make_gradient (proplist_t array, unsigned width, unsigned height,
       {
 	 GdkColor c;
 	 
-	 if (!gdk_color_parse (WMGetFromPLString (WMGetFromPLArray (array, k)), &c))
+	 if (!make_color (WMGetFromPLString (WMGetFromPLArray (array, k)), &c))
 	    c.red = c.green = c.blue = 65535; /* white */
 
 	 colors [k - start]        = Calloc (1, sizeof (RColor)) ;
@@ -190,7 +231,7 @@ make_solid (const char *color, unsigned width, unsigned height,
       unsigned x, y;
       GdkColor c;
       
-      if (!gdk_color_parse (color, &c))
+      if (!make_color (color, &c))
 	 c.red = c.green = c.blue = 65535; /* white */
       for (y = 0; y < height; y++)
       {
@@ -225,9 +266,9 @@ make_textured_gradient (const char *filename, proplist_t array,
 				  NULL, 10);
       RImage	*gradient, *image, *tiled;
       
-      if (!gdk_color_parse (WMGetFromPLString (WMGetFromPLArray (array, 3)), &c1))
+      if (!make_color (WMGetFromPLString (WMGetFromPLArray (array, 3)), &c1))
 	 c1.red = c1.green = c1.blue = 65535; /* white */
-      if (!gdk_color_parse (WMGetFromPLString (WMGetFromPLArray (array, 4)), &c2))
+      if (!make_color (WMGetFromPLString (WMGetFromPLArray (array, 4)), &c2))
 	 c2.red = c2.green = c2.blue = 65535; /* white */
       r1.red   = c1.red >> 8;
       r1.green = c1.green >> 8;
@@ -294,15 +335,15 @@ make_igradient (proplist_t array, unsigned width, unsigned height,
 				     NULL, 10);
       RImage	*gradient;
       
-      if (!gdk_color_parse (WMGetFromPLString (WMGetFromPLArray (array, 1)),
+      if (!make_color (WMGetFromPLString (WMGetFromPLArray (array, 1)),
 			    &from1))
 	 from1.red = from1.green = from1.blue = 65535; /* white */
-      if (!gdk_color_parse (WMGetFromPLString (WMGetFromPLArray (array, 2)), &to1))
+      if (!make_color (WMGetFromPLString (WMGetFromPLArray (array, 2)), &to1))
 	 to1.red = to1.green = to1.blue = 65535; /* white */
-      if (!gdk_color_parse (WMGetFromPLString (WMGetFromPLArray (array, 4)),
+      if (!make_color (WMGetFromPLString (WMGetFromPLArray (array, 4)),
 			    &from2))
 	 from2.red = from2.green = from2.blue = 65535; /* white */
-      if (!gdk_color_parse (WMGetFromPLString (WMGetFromPLArray (array, 5)), &to2))
+      if (!make_color (WMGetFromPLString (WMGetFromPLArray (array, 5)), &to2))
 	 to2.red = to2.green = to2.blue = 65535; /* white */
       
       r1 [0].red   = from1.red >> 8;
