@@ -66,6 +66,7 @@
 #include "menu.h"
 #include "load.h"
 #include "error.h"
+#include "dndtree.h"
 
 /*******************************************************************************
 
@@ -91,6 +92,7 @@ static const char *cmd_name [WM_LAST + 1];
 
 static GtkWidget *command_box       = NULL;
 static GtkWidget *itemlabel_entry   = NULL;
+static guint      itemlabel_entry_sig = 0;
 
 static GtkWidget *box_confirm_button      = NULL;
 static GtkWidget *box_commandline_entry   = NULL;
@@ -105,13 +107,18 @@ static GtkWidget *menu_tree          = NULL;
 static GtkWidget *command_menu       = NULL;
 static GtkWidget *confirm_button     = NULL;
 static GtkWidget *commandline_entry  = NULL;
+static guint      commandline_entry_sig = 0;
 static GtkWidget *wmanager_entry     = NULL;
+static guint      wmanager_entry_sig = 0;
 static GtkWidget *shortcut_widget    = NULL;
 static GtkWidget *include_file_entry = NULL;
+static guint      include_file_entry_sig = 0;
 static GtkWidget *pipe_command_entry = NULL;
+static guint      pipe_command_entry_sig = 0;
 static GtkWidget *dir_clist          = NULL;
 static GtkWidget *dir_remove         = NULL;
 static GtkWidget *dir_with_entry     = NULL;
+static guint      dir_with_entry_sig = 0;
 static GtkWidget *suffix_button      = NULL;
 
 static GtkWidget *notebook_page   = NULL;
@@ -529,8 +536,8 @@ real_rootmenu (GtkTooltips *tooltips, proplist_t menu)
       
       itemlabel_entry = gtk_entry_new ();
       gtk_box_pack_start (GTK_BOX (box), itemlabel_entry, TRUE, TRUE, 5);
-      gtk_signal_connect (GTK_OBJECT (itemlabel_entry), "changed",
-			  GTK_SIGNAL_FUNC (set_label),  NULL);
+      itemlabel_entry_sig = gtk_signal_connect (GTK_OBJECT (itemlabel_entry),
+				"changed", GTK_SIGNAL_FUNC (set_label),  NULL);
       gtk_widget_show_all (frame);
    }
 
@@ -587,8 +594,8 @@ real_rootmenu (GtkTooltips *tooltips, proplist_t menu)
 	 commandline_entry = gtk_entry_new ();
 	 gtk_box_pack_start (GTK_BOX (hbox), commandline_entry, TRUE, TRUE, 5);
       }
-      gtk_signal_connect (GTK_OBJECT (commandline_entry), "changed",
-			  GTK_SIGNAL_FUNC (set_entry_text), NULL);
+      commandline_entry_sig = gtk_signal_connect (GTK_OBJECT(commandline_entry),
+			  "changed", GTK_SIGNAL_FUNC (set_entry_text),  NULL);
       gtk_tooltips_set_tip (tooltips, commandline_entry,
 			    _("Commandline of application to execute. A %s "
 			      "directive is replaced by the current selection"
@@ -615,8 +622,9 @@ real_rootmenu (GtkTooltips *tooltips, proplist_t menu)
 			     FALSE, TRUE, 5);
 	 pipe_command_entry = gtk_entry_new ();
 	 gtk_box_pack_start (GTK_BOX (hbox), pipe_command_entry, TRUE, TRUE, 5);
-	 gtk_signal_connect (GTK_OBJECT (pipe_command_entry), "changed",
-			     GTK_SIGNAL_FUNC (set_entry_text), NULL);
+	 pipe_command_entry_sig = gtk_signal_connect
+				  (GTK_OBJECT (pipe_command_entry), "changed",
+				    GTK_SIGNAL_FUNC (set_entry_text),  NULL);
 	 gtk_tooltips_set_tip (tooltips, pipe_command_entry,
 			       _("Commandline to generate dynamic menu."), NULL);
       
@@ -656,8 +664,8 @@ real_rootmenu (GtkTooltips *tooltips, proplist_t menu)
 	 wmanager_entry = gtk_entry_new ();
 	 gtk_box_pack_start (GTK_BOX (hbox), wmanager_entry, TRUE, TRUE, 5);
       }
-      gtk_signal_connect (GTK_OBJECT (wmanager_entry), "changed",
-			  GTK_SIGNAL_FUNC (set_entry_text), NULL);
+      wmanager_entry_sig = gtk_signal_connect (GTK_OBJECT (wmanager_entry),
+			  "changed", GTK_SIGNAL_FUNC (set_entry_text),  NULL);
       gtk_tooltips_set_tip (tooltips, wmanager_entry,
 			    _("Name of window manager to start. "
 			      "If omitted, restart Window Maker."), NULL);
@@ -681,8 +689,9 @@ real_rootmenu (GtkTooltips *tooltips, proplist_t menu)
 			     FALSE, TRUE, 5);
 	 include_file_entry = gtk_entry_new ();
 	 gtk_box_pack_start (GTK_BOX (hbox), include_file_entry, TRUE, TRUE, 5);
-	 gtk_signal_connect (GTK_OBJECT (include_file_entry), "changed",
-			     GTK_SIGNAL_FUNC (set_entry_text), NULL);
+         include_file_entry_sig = gtk_signal_connect 
+				 (GTK_OBJECT (include_file_entry), "changed",
+				  GTK_SIGNAL_FUNC (set_entry_text),  NULL);
 	 gtk_tooltips_set_tip (tooltips, include_file_entry,
 			       _("Filename of menu to include."), NULL);
       
@@ -738,8 +747,8 @@ real_rootmenu (GtkTooltips *tooltips, proplist_t menu)
 			     FALSE, TRUE, 5);
 	 dir_with_entry = gtk_entry_new ();
 	 gtk_box_pack_start (GTK_BOX (hbox), dir_with_entry, TRUE, TRUE, 5);
-	 gtk_signal_connect (GTK_OBJECT (dir_with_entry), "changed",
-			     GTK_SIGNAL_FUNC (dir_list_to_item), NULL);
+         dir_with_entry_sig = gtk_signal_connect (GTK_OBJECT (dir_with_entry),
+			"changed", GTK_SIGNAL_FUNC (dir_list_to_item),  NULL);
 	 gtk_tooltips_set_tip (tooltips, dir_with_entry,
 			       _("Recursively, a submenu with all files and"
 				 " subdirectories of the given directory list is"
@@ -1122,7 +1131,9 @@ selection_made (GtkCTree *ctree, GtkCTreeNode *node, gint column,
       return;
    gtk_ctree_get_node_info (GTK_CTREE (menu_tree), node, &text, 
 			    NULL, NULL, NULL, NULL, NULL, NULL, NULL);
+   g_signal_handler_block (itemlabel_entry, itemlabel_entry_sig);
    gtk_entry_set_text (GTK_ENTRY (itemlabel_entry), text);
+   g_signal_handler_unblock (itemlabel_entry, itemlabel_entry_sig);
    show_action_dialog (gtk_ctree_node_get_row_data (GTK_CTREE (menu_tree), node));
    menu_changed = changed;
 }
@@ -1133,7 +1144,7 @@ set_label (GtkWidget *widget, gpointer ptr)
  *  Set label of submenu or command.
  */
 {
-   char		*label = gtk_entry_get_text (GTK_ENTRY (itemlabel_entry));
+   const char	*label = gtk_entry_get_text (GTK_ENTRY (itemlabel_entry));
    GtkCTreeNode *node  = (GTK_CLIST (menu_tree)->selection)->data;
    item_t	*item  = gtk_ctree_node_get_row_data (GTK_CTREE (menu_tree),
 						      node);
@@ -1218,25 +1229,36 @@ show_action_dialog (item_t *item)
    gtk_widget_hide (box_dir_widget);
    gtk_widget_hide (box_suffix_button);
       
+   if (item->action > WM_MENU)
+      gtk_option_menu_set_history (GTK_OPTION_MENU (command_menu),
+				   item->action - 1);
    if (item->action == WM_EXEC || item->action == WM_SHEXEC) /* show cmdline */
    {
+      guint sighandler = GPOINTER_TO_INT (gtk_object_get_user_data
+					  (GTK_OBJECT (commandline_entry)));
       if (!item->arg)
 	 item->arg = g_strdup ("");
+      g_signal_handler_block (commandline_entry, commandline_entry_sig);
       gtk_entry_set_text (GTK_ENTRY (commandline_entry), item->arg);
+      g_signal_handler_unblock (commandline_entry, commandline_entry_sig);
       gtk_widget_show (box_commandline_entry);
    }
    else if (item->action == WM_INCLUDE)	/* show include file entry */
    {
       if (!item->arg)
 	 item->arg = g_strdup ("");
+      g_signal_handler_block (include_file_entry, include_file_entry_sig);
       gtk_entry_set_text (GTK_ENTRY (include_file_entry), item->arg);
+      g_signal_handler_unblock (include_file_entry, include_file_entry_sig);
       gtk_widget_show (box_include_file_widget);
    }
    else if (item->action == WM_PIPE)	/* show pipe commandline entry */
    {
       if (!item->arg)
 	 item->arg = g_strdup ("");
+      g_signal_handler_block (pipe_command_entry, pipe_command_entry_sig);
       gtk_entry_set_text (GTK_ENTRY (pipe_command_entry), item->arg);
+      g_signal_handler_unblock (pipe_command_entry, pipe_command_entry_sig);
       gtk_widget_show (box_pipe_cmd_widget);
    }
    else if (item->action == WM_EXIT
@@ -1248,10 +1270,12 @@ show_action_dialog (item_t *item)
    }
    else if (item->action == WM_RESTART)	/* show windowmanger entry */
    {
+      g_signal_handler_block (wmanager_entry, wmanager_entry_sig);
       if (item->arg)
 	 gtk_entry_set_text (GTK_ENTRY (wmanager_entry), item->arg);
       else
 	 gtk_entry_set_text (GTK_ENTRY (wmanager_entry), "");
+      g_signal_handler_unblock (wmanager_entry, wmanager_entry_sig);
       gtk_widget_show (box_wmanager_entry);
    }
    else if (item->action == WM_OPEN_MENU) /* show directory list */
@@ -1283,7 +1307,9 @@ show_action_dialog (item_t *item)
 	    {
 	       while (*end && isspace (*end))
 		  end++;
+	       g_signal_handler_block (dir_with_entry, dir_with_entry_sig);
 	       gtk_entry_set_text (GTK_ENTRY (dir_with_entry), end);
+	       g_signal_handler_unblock (dir_with_entry, dir_with_entry_sig);
 	       Free (dir);
 	       break;
 	    }
@@ -1795,7 +1821,8 @@ open_filebrowser (GtkWidget *button, gpointer data)
 				 GTK_SIGNAL_FUNC (gtk_widget_destroy),
 				 GTK_OBJECT (filesel));
       {
-	 char *filename = gtk_entry_get_text (GTK_ENTRY (include_file_entry));
+	 const char *filename =
+	   gtk_entry_get_text (GTK_ENTRY (include_file_entry));
 
 	 if (streq (filename, ""))
 	    gtk_file_selection_set_filename (fs, WMAKERDIR "/");
@@ -1816,8 +1843,10 @@ set_filename (GtkWidget *button, gpointer data)
 {
    GtkFileSelection *fs = GTK_FILE_SELECTION (data);
 
+   g_signal_handler_block (include_file_entry, include_file_entry_sig);
    gtk_entry_set_text (GTK_ENTRY (include_file_entry),
 		       gtk_file_selection_get_filename (fs));
+   g_signal_handler_unblock (include_file_entry, include_file_entry_sig);
    gtk_entry_set_position (GTK_ENTRY (include_file_entry), -1);
    toggle_save (menu_changed = YES, NULL);
 }
@@ -2205,6 +2234,7 @@ dir_list_to_item (GtkWidget *button, gpointer data)
    int		n;
    unsigned	len = 0;
    char		*text;
+   const char   *ctext;
    GtkCTreeNode *node = (GTK_CLIST (menu_tree)->selection)->data;
    item_t	*item = gtk_ctree_node_get_row_data (GTK_CTREE (menu_tree), node);
 
@@ -2215,10 +2245,10 @@ dir_list_to_item (GtkWidget *button, gpointer data)
       gtk_clist_get_text (GTK_CLIST (dir_clist), n, 0, &text);
       len += strlen (text) + 1;
    }
-   if (strlen (text = gtk_entry_get_text (GTK_ENTRY (dir_with_entry))) > 0)
+   if (strlen (ctext = gtk_entry_get_text (GTK_ENTRY (dir_with_entry))) > 0)
    {
       len += strlen ("WITH ");
-      len += strlen (text) + 1;
+      len += strlen (ctext) + 1;
    }
    if (!len)
       return;				/* should not happen ;-) */
@@ -2236,10 +2266,10 @@ dir_list_to_item (GtkWidget *button, gpointer data)
       if (n != GTK_CLIST (dir_clist)->rows - 1)
 	 strcat (item->arg, " ");
    }
-   if (strlen (text = gtk_entry_get_text (GTK_ENTRY (dir_with_entry))) > 0)
+   if (strlen (ctext = gtk_entry_get_text (GTK_ENTRY (dir_with_entry))) > 0)
    {
       strcat (item->arg, " WITH ");
-      strcat (item->arg, text);
+      strcat (item->arg, ctext);
    }
    toggle_save (menu_changed = YES, NULL);
 }
@@ -2361,7 +2391,7 @@ static void
 convert_wmaker_menu (GtkWidget *button, gpointer data)
 {
    GtkFileSelection	*fs   = GTK_FILE_SELECTION (data);
-   char			*menu = gtk_file_selection_get_filename (fs);
+   const char		*menu = gtk_file_selection_get_filename (fs);
 
    gtk_widget_destroy (info_message);
    gtk_box_pack_start (GTK_BOX (notebook_page),
