@@ -21,16 +21,16 @@
  */
 
 /*
- *  $Date: 1998/12/20 18:53:02 $
+ *  $Date: 2000/01/24 19:56:09 $
  *  $Author: hafner $
- *  $Revision: 1.4 $
+ *  $Revision: 1.5 $
  *  $State: Exp $
  */
 
 #ifndef _ROOTMENU_H
 #define _ROOTMENU_H
 
-void
+GtkWidget *
 rootmenu_dialog (GtkWidget *page, GtkTooltips *tooltips);
 bool_t
 rootmenu_changed (void);
