@@ -17,9 +17,9 @@
 #define _SHORTCUTS_H
 
 #include <gtk/gtk.h>
-#include <proplist.h>
+#include "proplist_t.h"
 
 void
-add_shortcut (GtkWidget *page, proplist_t *key);
+add_shortcut (GtkWidget *page, proplist_t key);
 
 #endif /* not _SHORTCUTS_H */
