@@ -30,6 +30,7 @@
 #include "config.h"
 
 #include <stdio.h>
+#include <stdlib.h>
 
 #include <gtk/gtk.h>
 #include "proplist_t.h"
@@ -90,6 +91,10 @@ set_int (GtkWidget *widget, gpointer ptr);
 static void
 set_entry_text (GtkWidget *widget, gpointer ptr);
 static void
+convert_pango_to_fontconfig (const char *pangoname, char *fcname);
+static void
+convert_fontconfig_to_pango (const char *fcname, char *pangoname);
+static void
 set_fontname (GtkWidget *widget, gpointer ptr);
 static void
 fontsel_dialog (GtkWidget *widget, gpointer ptr);
@@ -684,17 +689,21 @@ fontsel_dialog (GtkWidget *widget, gpointer ptr)
   if (!fontsel)
   {
      GtkWidget			*entry;
-     char			*text;
+     const char			*text;
+     char			*pangotext;
      GtkFontSelectionDialog	*fs;
      
      entry   = GTK_WIDGET (ptr);
      text    = gtk_entry_get_text (GTK_ENTRY (entry));
+     pangotext = malloc (strlen (text) + 1);
      fontsel = gtk_font_selection_dialog_new (_("Font selection"));
      fs	     = GTK_FONT_SELECTION_DIALOG (fontsel);
      
      gtk_window_set_position (GTK_WINDOW (fontsel), GTK_WIN_POS_MOUSE);
      gtk_object_set_user_data (GTK_OBJECT (fontsel), entry);
-     gtk_font_selection_dialog_set_font_name (fs, text);
+     convert_fontconfig_to_pango (text, pangotext);
+     gtk_font_selection_dialog_set_font_name (fs, pangotext);
+     free (pangotext);
 
      gtk_object_set_data (GTK_OBJECT (entry), "fontsel", fontsel);
      gtk_signal_connect (GTK_OBJECT (fontsel), "destroy",
@@ -716,15 +725,146 @@ fontsel_dialog (GtkWidget *widget, gpointer ptr)
      gtk_widget_destroy (fontsel);
 }
 
+struct font_attr_t {
+  int slant;
+  int weight;
+  int width;
+  int size;
+};
+
+/* Function to convert from GTK+ 2's Pango font names to the slightly
+ * different format used by WindowMaker 0.90 (fontconfig?)
+ * fcname must already be allocated and have a length of at least
+ * strlen(pangoname) + 50. */
+static void
+convert_pango_to_fontconfig (const char *pangoname, char *fcname)
+{
+  const char * posn;
+  char * base;
+  int size;
+  struct font_attr_t attr = { 0, 80, 100, 12 };
+
+  posn = pangoname + strlen(pangoname) - 1;
+  while (posn > pangoname && isdigit(*posn)) posn--;
+  
+  size = atoi(posn);
+  if (size) attr.size = size;
+
+  /* check for italic */
+  if (posn - pangoname > 6 && strncmp(posn - 6, "Italic", 6) == 0) {
+    attr.slant = 100;
+    posn -= 7;
+  }
+
+  /* check for condensed */
+  if (posn - pangoname > 9 && strncmp(posn - 9, "Condensed", 9) == 0) {
+    attr.width = 75;
+    posn -= 10;
+  }
+
+  /* check for bold */
+  if (posn - pangoname > 9 && strncmp(posn - 9, "Semi-Bold", 9) == 0) {
+    attr.weight = 100;
+    posn -= 10;
+  }
+  else if (posn - pangoname > 4 && strncmp(posn - 4, "Bold", 4) == 0) {
+    attr.weight = 200;
+    posn -= 5;
+  }
+
+  if (posn > pangoname && *(posn - 1) == ',')
+    posn--;
+
+  base = malloc(posn - pangoname + 10);
+  strncpy(base, pangoname, posn - pangoname);
+  base[posn - pangoname] = 0;
+
+  /* Sans and Serif aliases are slightly different in Pango vs. fontconfig */
+  if (strcmp(base, "Sans") == 0)
+    strcpy(base, "sans serif");
+  else if (strcmp(base, "Serif") == 0)
+    strcpy(base, "serif");
+  
+  sprintf(fcname, "%s:slant=%d:weight=%d:width=%d:pixelsize=%d",
+	  base, attr.slant, attr.weight, attr.width, attr.size);
+  free(base);
+}
+
+/* Function to convert from WindowMaker 0.90's fontconfig font name format
+ * to that used by Pango in GTK+ 2.
+ * pangoname must already be allocated and have a length of at least
+ * strlen(fcname). */
+static void
+convert_fontconfig_to_pango (const char *fcname, char *pangoname)
+{
+  char * base, * posn, * posn2;
+  char slant[8] = { 0 }, weight[11] = { 0 }, width[11] = { 0 };
+  int size = 12;
+
+  /* Find the first ':' or ',' and assume this is the end of the font name */
+  posn = strchr(fcname, ':');
+  posn2 = strchr(fcname, ',');
+  if (!posn || posn2 && posn2 < posn)
+    posn = posn2;
+  
+  if (posn) {
+    base = malloc(posn - fcname + 1);
+    strncpy(base, fcname, posn - fcname);
+    base[posn - fcname] = 0;
+  }
+  else {
+    /* maybe XLFD, don't touch */
+    strcpy(pangoname, fcname);
+    return;
+  }
+
+  /* Sans and Serif aliases are slightly different in Pango vs. fontconfig */
+  if (strcmp(base, "sans serif") == 0)
+    strcpy(base, "Sans");
+  else if (strcmp(base, "serif") == 0)
+    strcpy(base, "Serif");
+ 
+  if ((posn = strstr(fcname, ":weight="))) {
+    int wt = atoi(posn + 8);
+    if (wt >= 150)
+      strcpy(weight, "Bold ");
+    else if (wt >= 90)
+      strcpy(weight, "Semi-Bold ");
+  }
+
+  if ((posn = strstr(fcname, ":bold")))
+    strcpy(weight, "Bold ");
+  
+  if ((posn = strstr(fcname, ":width=")))
+    if (atoi(posn + 7) < 90)
+      strcpy(width, "Condensed ");
+  
+  if ((posn = strstr(fcname, ":slant=")))
+    if (atoi(posn + 7))
+      strcpy(slant, "Italic ");
+
+  if ((posn = strstr(fcname, ":pixelsize="))) {
+    int sz = atoi(posn + 11);
+    if (sz) size = sz;
+  }
+    
+  sprintf(pangoname, "%s, %s%s%s%d", base, weight, width, slant, size);
+  free(base);
+}
+
 static void
 set_fontname (GtkWidget *widget, gpointer ptr)
 {
    GtkWidget *fontsel = GTK_WIDGET (ptr);
    GtkWidget *entry   = gtk_object_get_user_data (GTK_OBJECT (fontsel));
    gchar     *fontname;
+   gchar     *fontconfigname;
 
    fontname = gtk_font_selection_dialog_get_font_name (GTK_FONT_SELECTION_DIALOG (fontsel));
-   gtk_entry_set_text (GTK_ENTRY (entry), fontname);
+   fontconfigname = malloc(strlen(fontname) + 50);
+   convert_pango_to_fontconfig(fontname, fontconfigname);
+   gtk_entry_set_text (GTK_ENTRY (entry), fontconfigname);
+   free(fontconfigname);
 }
 
 static void
@@ -742,7 +882,8 @@ update_color (proplist_t key, gpointer ptr, proplist_t value,
    if (WMIsPLString (value))
    {
       GtkWidget  *preview  = GTK_WIDGET (ptr);
-      proplist_t oldvalue  = gtk_object_get_user_data (GTK_OBJECT (preview));
+      //the below wasn't used; was it supposed to be?
+      //proplist_t oldvalue  = gtk_object_get_user_data (GTK_OBJECT (preview));
 
       WMRetainPropList (value);
       gtk_object_set_user_data (GTK_OBJECT (preview), value);
